package androidx.core.app;

import X6FRs_4.Eps4cJe_18.KQgRr5e_0;
import X6FRs_4.Eps4cJe_18.PGPF6hQ_2;
import android.app.PendingIntent;
import android.os.Parcelable;
import androidx.core.graphics.drawable.IconCompat;
/* loaded from: classes.dex */
public class RemoteActionCompatParcelizer {
    public static RemoteActionCompat read(KQgRr5e_0 kQgRr5e_0) {
        RemoteActionCompat remoteActionCompat = new RemoteActionCompat();
        remoteActionCompat.f2235KQgRr5e_0 = (IconCompat) kQgRr5e_0.KQgRr5e_0((KQgRr5e_0) remoteActionCompat.f2235KQgRr5e_0, 1);
        remoteActionCompat.f2236KQgRr5e_0 = kQgRr5e_0.KQgRr5e_0(remoteActionCompat.f2236KQgRr5e_0, 2);
        remoteActionCompat.QxJ9d_1 = kQgRr5e_0.KQgRr5e_0(remoteActionCompat.QxJ9d_1, 3);
        remoteActionCompat.KQgRr5e_0 = (PendingIntent) kQgRr5e_0.KQgRr5e_0((KQgRr5e_0) remoteActionCompat.KQgRr5e_0, 4);
        remoteActionCompat.f2237KQgRr5e_0 = kQgRr5e_0.m207KQgRr5e_0(remoteActionCompat.f2237KQgRr5e_0, 5);
        remoteActionCompat.f2238QxJ9d_1 = kQgRr5e_0.m207KQgRr5e_0(remoteActionCompat.f2238QxJ9d_1, 6);
        return remoteActionCompat;
    }

    public static void write(RemoteActionCompat remoteActionCompat, KQgRr5e_0 kQgRr5e_0) {
        kQgRr5e_0.KQgRr5e_0(false, false);
        kQgRr5e_0.m200KQgRr5e_0((PGPF6hQ_2) remoteActionCompat.f2235KQgRr5e_0, 1);
        kQgRr5e_0.m202KQgRr5e_0(remoteActionCompat.f2236KQgRr5e_0, 2);
        kQgRr5e_0.m202KQgRr5e_0(remoteActionCompat.QxJ9d_1, 3);
        kQgRr5e_0.m201KQgRr5e_0((Parcelable) remoteActionCompat.KQgRr5e_0, 4);
        kQgRr5e_0.KQgRr5e_0(remoteActionCompat.f2237KQgRr5e_0, 5);
        kQgRr5e_0.KQgRr5e_0(remoteActionCompat.f2238QxJ9d_1, 6);
    }
}
